export interface UseCounterProps {
    /**
     * The number of decimal points used to round the value
     */
    precision?: number;
    /**
     * The initial value of the counter. Should be less than `max` and greater than `min`
     */
    defaultValue?: string | number;
    /**
     * The step used to increment or decrement the value
     * @default 1
     */
    step?: number;
    /**
     * The minimum value of the counter
     * @default Number.MIN_SAFE_INTEGER
     */
    min?: number;
    /**
     * The maximum value of the counter
     * @default Number.MAX_SAFE_INTEGER
     */
    max?: number;
    /**
     * This controls the value update behavior in general.
     *
     * - If `true` and you use the stepper or up/down arrow keys,
     *  the value will not exceed the `max` or go lower than `min`
     *
     * - If `false`, the value will be allowed to go out of range.
     *
     * @default true
     */
    keepWithinRange?: boolean;
}
/**
 * Composable providing step functionality
 */
export declare function useCounter(props?: UseCounterProps): {
    decrement: (step?: number) => void;
    increment: (step?: number) => void;
    update: (next: string | number) => void;
    valueAsNumber: import("vue").Ref<number>;
    isOutOfRange: import("vue").Ref<boolean>;
    value: import("vue").Ref<string | number>;
};
//# sourceMappingURL=use-counter.d.ts.map